import { HttpClient, HttpResponse } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { Observable } from 'rxjs';
import { environment } from 'src/environments/environment';
import { Project } from '../models/project';
import { ProjectRevision } from '../models/project-revision';

@Injectable({
  providedIn: 'root'
})
export class ProjectsService {

  constructor(private httpClient: HttpClient) { }

  public getProjects(): Observable<HttpResponse<Project[]>> {
    return this.httpClient.get<Project[]>(`${environment.apiBaseUrl}project-service/projects`, {
      observe: 'response',
    });
  }

  public getProjectById(id: string): Observable<HttpResponse<Project>> {
    return this.httpClient.get<Project>(`${environment.apiBaseUrl}project-service/projects/${id}`, {
      observe: 'response',
    });
  }

  public getRevisions(projectId: string, includeJobInformation: boolean = true): Observable<ProjectRevision[]> {
    return this.httpClient.get<ProjectRevision[]>(`${environment.apiBaseUrl}project-service/projects/${projectId}/revisions?job-info=${includeJobInformation}`, {
      observe: 'body'
    });
  }

  public createProject(project: Project): Observable<string> {
    return this.httpClient.post<string>(`${environment.apiBaseUrl}project-service/projects`, {
      name: project.name,
      description: project.description,
      jobRunnerId: project.jobRunnerId,
      inputEndpoints: project.inputEndpoints,
      selectedOutputEndpointId: project.selectedOutputEndpointId,
      outputEndpoints: project.outputEndpoints
    });
  }

  public createRevision(projectId: string): Observable<string> {
    return this.httpClient.post<string>(`${environment.apiBaseUrl}project-service/projects/${projectId}/revisions`, null, {
      observe: 'body'
    });
  }

  public updateProject(id: string, entity: Project): Observable<Project> {
    return this.httpClient.patch<Project>(`${environment.apiBaseUrl}project-service/projects/${id}`,
    [
      {
        op: 'replace',
        path: '/name',
        value: entity.name,
      },
      {
        op: 'replace',
        path: '/description',
        value: entity.description,
      },
      {
        op: 'replace',
        path: '/jobRunnerId',
        value: entity.jobRunnerId,
      },
      {
        op: 'replace',
        path: '/inputEndpoints',
        value: entity.inputEndpoints,
      },
      {
        op: 'replace',
        path: '/selectedOutputEndpointId',
        value: entity.selectedOutputEndpointId
      },
      {
        op: 'replace',
        path: '/outputEndpoints',
        value: entity.outputEndpoints,
      }
    ], {
      observe: 'body',
    });
  }

  public deleteProject(id: string): Observable<any> {
    return this.httpClient.delete(`${environment.apiBaseUrl}project-service/projects/${id}`);
  }

  public getRevisionLogs(revisionId: string): Observable<string[]> {
    return this.httpClient.get<string[]>(`${environment.apiBaseUrl}project-service/revisions/${revisionId}/logs`, {
      observe: 'body',
    });
  }
}
